use mquery::{
    query::{self, Metric},
    Auth, QueryManager,
};
use tokio::runtime::Runtime;

mod utils;

// TODO: Create proper tests with local server
#[test]
fn deserialize_response() {
    let (url, token) = get_url_token();
    let rt = Runtime::new().unwrap();
    let query = format!(
        "sum(M40c82231{{uuid=\"{}\"}}[10d])",
        "1bed9384-5d24-11e3-abe4-2d513ee73a00"
    );
    let _ = rt
        .block_on(
            QueryManager::new(url.parse().unwrap())
                .auth(Auth::Bearer(token))
                .query(query),
        )
        .unwrap();
}

#[test]
fn query_with_metric_selector() {
    let metric = query::Metric::new("some_metric");
    #[allow(clippy::let_underscore_future)]
    let _ = QueryManager::default().query(metric);
}

#[cfg(feature = "multi")]
#[tokio::test]
async fn multi_queries() {
    let res = QueryManager::new(utils::URL.parse().unwrap())
        .query_multi([Metric::new("metric"), Metric::new("metric_two")])
        .await
        .expect("failed to get multi query result");
    assert!(res.len() == 2);
}

fn get_url_token() -> (String, String) {
    dotenv::dotenv().expect("No .env file found in working dir");
    (
        std::env::var("VM_URL").expect("VM URL not found in env"),
        std::env::var("VM_TOKEN").expect("VM URL not found in env"),
    )
}
